@@ -8,7 +8,7 @@ use Scalar::Util 'weaken';
 use Sereal::Decoder 'sereal_decode_with_object';
 use Sereal::Encoder 'sereal_encode_with_object';
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 our @EXPORT = '$_subprocess';
 
@@ -63,9 +63,6 @@ supports serialization of more reference types such as C<Regexp>. The
 L<Sereal::Encoder/"FREEZE/THAW CALLBACK MECHANISM"> is supported to control
 serialization of blessed objects.
 
-Note that L<Mojo::IOLoop::Subprocess> is EXPERIMENTAL and thus so is this
-module!
-
 =head1 EXPORTS
 
 L<Mojo::IOLoop::Subprocess::Sereal> exports the following variable by default.
